@@ -235,7 +235,7 @@ END
 
    DATA_SOURCE => 'Data Source',
 
-   UPLOADED_TRACKS => 'Uploaded Tracks',
+   UPLOADED_TRACKS => 'Custom Tracks',
 
    IMPORTED_TRACKS => 'Imported Tracks',
 
@@ -249,6 +249,8 @@ END
 
    UPLOAD_FILE => 'Upload a track file',
 
+   MIRROR_FILE  => 'Fetch track file from this URL',
+
    IMPORT_TRACK => 'Import a track URL',
 
    NEW_TRACK    => 'Create a new track',
@@ -257,6 +259,8 @@ END
 
    FROM_FILE    => 'From a file',
 
+   FROM_URL    => 'From a URL',
+
    REMOVE       => 'Remove',
 
    KEY_POSITION => 'Key position',
@@ -318,6 +322,7 @@ END
 
    NAME           => 'Name',
    TYPE           => 'Type',
+   SUBTYPE         => 'subtype',
    DESCRIPTION    => 'Description',
    POSITION       => 'Position',
    SCORE          => 'Match Score',
@@ -472,7 +477,7 @@ END
 
  GLYPH            => 'Shape',
 
- XYPLOT_TYPE      => 'xyplot subtype',
+ XYPLOT_TYPE      => 'plot style',
 
  WHISKERS_TYPE      => 'whiskers subtype',
 
@@ -490,6 +495,10 @@ END
 
  WHISKER_MAX_COLOR    => 'Color from stdev to min/max value',
 
+ AUTOSCALING      => 'Y-axis scaling',
+
+ SCALING          => 'Fixed Y-axis range',
+
  SCALE_MIN        => 'Minimum scale value',
 
  SCALE_MAX        => 'Maximum scale value',
@@ -554,15 +563,15 @@ END
  SHARE_INSTRUCTIONS_ONE_TRACK => <<END,
 To <b>export</b> this track to a different GBrowse genome browser,
 first copy the URL below, then go to the other GBrowse, 
-select the "Upload and Share Tracks" tab and
-paste the URL into the "Import tracks" section at the bottom.
+select the "Upload and Share Tracks" tab, click the "From a URL" link
+and paste in the URL.
 END
 
  SHARE_INSTRUCTIONS_ALL_TRACKS => <<END,
 To export all currently selected tracks to another GBrowse genome
 browser, first copy the URL below, then go to the other GBrowse,
-select the "Upload and Share Tracks" tab and
-paste the URL into the "Import tracks" section at the bottom.
+select the "Upload and Share Tracks" tab, click the "From a URL" link
+and paste in the URL.
 END
 
  SHARE_DAS_INSTRUCTIONS_ONE_TRACK => <<END,
