@@ -1,5 +1,5 @@
 package Bio::Graphics::Browser2::DataLoader;
-# $Id: DataLoader.pm 23705 2010-08-26 21:59:09Z lstein $
+# $Id: DataLoader.pm 24024 2010-10-22 20:30:41Z lstein $
 
 use strict;
 use IO::File;
@@ -262,6 +262,7 @@ sub load {
 
 	$self->set_status('load data');
 
+	my $count = 0;
 	my $eol   = $self->eol_char;
 	{
 	    local $/  = $eol if $eol;
@@ -271,7 +272,7 @@ sub load {
 		$self->load_line($_);
 	    }
 
-	    my $count = @$initial_lines;
+	    $count = @$initial_lines;
 	    while (<$fh>) {
 		$source_file->print($_) if $source_file;
 		$self->load_line($_);
@@ -280,7 +281,7 @@ sub load {
 	    $source_file->close;
 	}
 
-	$self->finish_load;
+	$self->finish_load($count);
 	$self->close_conf;
     };
     $self->flag_busy(0);
